<!--隐患档案查询-->
<template>
  <div class="mobile-device">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="人员管理"
        left-arrow
        @click-left="_ => $router.go(-1)"
        @click-right="showPopup('querySearchPopup')"
      >
        <template #right>
          <van-icon name="search" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>

    <van-pull-refresh
      v-model="refreshing"
      @refresh="onRefresh"
      class="van-hairline--top"
    >
      <van-list
        v-model="loading"
        :finished="finished"
        finished-text="没有更多了"
        @load="onLoad"
        :immediate-check="false"
      >
        <div
          v-for="(item, index) in listData"
          :key="index"
          class="device van-hairline--bottom"
          :class="{myStyle: index === listData.length - 1}"
          @click="boxClick(item)"
        >
          <div class="device-item">
            <div class="device-item-left">
              <van-icon name="van-icon van-icon-manager" size="45px" color="#5e9df0" />
            </div>
            <div class="device-content">
              <p>
                <span class="label">账号名：</span>
                <span class="value">{{ item.account || '-' }}</span>
              </p>
              <p>
                <span class="label">人员姓名：</span>
                <span class="value">{{ item.fullname || '-' }}</span>
              </p>
              <p>
                <span class="label">联系电话：</span>
                <span class="value">{{ item.mobile || '-' }}</span>
              </p>
              <p>
                <span class="label">性别：</span>
                <span class="value">{{ item.sex || '-' }}</span>
              </p>

            </div>
          </div>
        </div>
      </van-list>
    </van-pull-refresh>


    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="customQueryPrams"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import {Toast} from 'vant'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'
import dictUtils from '@/components/dict/DictSelectUtils'
import {listData} from '@/api/Mobile/personnelManagement'
import {dictionaryEscape} from '@/utils/dictionary'

const {getDictItemsFromCache} = dictUtils // 解构出获取字典函数

export default {
  name: 'PersonnelManagement',
  components: {QuerySearchPopup},
  // 隐患档案查询
  data() {
    return {
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        account: '',  // 账号名
        fullname: '', // 人员姓名
        mobile: '', // 联系电话
        DEM_ID_: '' // 组织ID（部门ID）
      },
      sorter: [],
      listData: [],// 列表数据
      loading: false, // 列表是否触发loading
      finished: false, // 列表是否加载完成
      refreshing: false, // 列表是否开始下拉刷新
      querySearchPopup: false // 搜索弹层
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑(应对于Vant2下拉框无转义功能)
      *  为重新加工结构赋值的新请求配置参数
      * */
      const querys = [
        {property: 'account', operation: 'LIKE', group: 'quick', relation: 'OR'},
        {property: 'fullname', operation: 'LIKE', group: 'quick', relation: 'OR'},
        {property: 'mobile', operation: 'LIKE', group: 'quick', relation: 'OR'},
        {property: 'DEM_ID_', operation: 'EQUAL', group: 'orgTree', relation: 'AND'}
      ]
      const escapeOpt = {}
      return {
        pageBean: {pageSize, page},
        querys: querys.flatMap(i => {
          // 获取value值优先级：customQueryPrams.value > querys[i].value
          let value = item[i.property] || i.value || ''
          if (Array.isArray(value) && !value.length) return []
          if (value === '') return []
          let escape = this[escapeOpt[i.property]]  // 找寻翻译配置项
          if (escape) value = this.dictionaryEscape(escape, value, {dictionaryType: false})
          return {operation: 'LIKE', group: 'main', relation: 'AND', ...i, value}
        }),
        sorter: this.sorter.filter(i => i.direction !== '')
      }
    }
  },
  created() {
    this.getListData()
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape,

    // 跳转设备详情
    boxClick({id, account}) {
      if (!id) return Toast.fail('人员信息错误')
      this.$router.push({
        name: 'accountDetails',
        query: {id, account}
      })
    },
    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData(_ => this.loading = false)
    },

    // 下拉时触发
    onRefresh() {
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData(_ => this.refreshing = false)
    },

    // 打开弹层
    showPopup(popupName) {
      this[popupName] = true
    },

    // 获取列表数据
    async getListData(callback) {
      const {rows, total} = await listData(this.queryParams)
      const {pageSize, page} = this.customQueryPrams
      this.listData = this.listData.concat(rows)
      this.$nextTick(_ => callback && callback())
      if (pageSize * page >= total) this.finished = true
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    }
  }
}
</script>


<style lang="scss" scoped>
@import '@/assets/css/element-variables';


.device {
  background-color: #f9f9f9;
  padding: 40px 40px 20px 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  width: 100%;

  .device-item {
    display: flex;
    column-gap: 100px;
    background-color: #fff;
    border-radius: 40px;
    padding: 60px 110px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);

    .device-item-left {
      display: flex;
      align-items: center;
    }

    .device-content {
      display: flex;
      flex-direction: column;
      row-gap: 20px;
      flex: 1;

      p {
        margin: 0;
        display: flex;

        .label {
          color: #333;
          font-size: 60px;
          flex: 3;
        }

        .value {
          font-size: 60px;
          flex: 8;
        }
      }
    }
  }


}

</style>


<style lang="scss">
@import '@/assets/css/vant-custom';
</style>


